@@ -22,18 +22,15 @@ OpenStack Client interface. Handles the REST calls and responses.
 from __future__ import print_function
 
 import logging
-import requests
 
-from keystoneclient import adapter
+from keystoneauth1 import adapter
 from oslo_utils import importutils
-from troveclient.openstack.common.apiclient import client
-from troveclient.openstack.common.apiclient import exceptions
-from troveclient import service_catalog
+import requests
+import six.moves.urllib.parse as urlparse
 
-try:
-    import urlparse
-except ImportError:
-    import urllib.parse as urlparse
+from troveclient.apiclient import client
+from troveclient import exceptions
+from troveclient import service_catalog
 
 try:
     import eventlet as sleep_lib
@@ -208,7 +205,7 @@ class HTTPClient(TroveClientMixin):
                 resp, body = self.request(self.management_url + url, method,
                                           **kwargs)
                 return resp, body
-            except exceptions.BadRequest as e:
+            except exceptions.BadRequest:
                 if attempts > self.retries:
                     raise
             except exceptions.Unauthorized:
