@@ -21,9 +21,9 @@ import os
 import mock
 import testtools
 
+from troveclient.apiclient import exceptions
 from troveclient import base
 from troveclient import common
-from troveclient.openstack.common.apiclient import exceptions
 from troveclient import utils
 
 """
@@ -87,10 +87,6 @@ class ManagerTest(testtools.TestCase):
 
         # no cache object, nothing should happen
         manager.write_to_completion_cache("non-exist", "val")
-
-        def side_effect_func(val):
-            return val
-
         manager._mock_cache = mock.Mock()
         manager._mock_cache.write = mock.Mock(return_value=None)
         manager.write_to_completion_cache("mock", "val")
@@ -214,9 +210,6 @@ class ManagerListTest(ManagerTest):
     def tearDown(self):
         super(ManagerListTest, self).tearDown()
 
-    def obj_class(self, res, loaded=True):
-        return res
-
     def test_list_with_body_none(self):
         body = None
         l = self.manager._list("url", self.response_key, obj_class, body)
@@ -296,21 +289,21 @@ class MangerPaginationTests(ManagerTest):
     def test_pagination(self):
         resp = self.manager._paginated(self.url, self.response_key)
         self.manager.api.client.get.assert_called_with(self.url)
-        self.assertEqual('p1', resp.items[0].foo)
-        self.assertEqual('p2', resp.items[1].foo)
+        self.assertEqual('p1', resp[0].foo)
+        self.assertEqual('p2', resp[1].foo)
         self.assertEqual(self.marker, resp.next)
         self.assertEqual(self.links, resp.links)
-        self.assertTrue(isinstance(resp, common.Paginated))
+        self.assertIsInstance(resp, common.Paginated)
 
     def test_pagination_next(self):
         resp = self.manager._paginated(self.url, self.response_key,
                                        limit=self.limit, marker=self.marker)
         self.manager.api.client.get.assert_called_with(self.next_url)
-        self.assertEqual('p3', resp.items[0].foo)
-        self.assertEqual('p4', resp.items[1].foo)
-        self.assertEqual(None, resp.next)
+        self.assertEqual('p3', resp[0].foo)
+        self.assertEqual('p4', resp[1].foo)
+        self.assertIsNone(resp.next)
         self.assertEqual([], resp.links)
-        self.assertTrue(isinstance(resp, common.Paginated))
+        self.assertIsInstance(resp, common.Paginated)
 
     def test_pagination_error(self):
         self.manager.api.client.get = mock.Mock(return_value=(None, None))
@@ -490,28 +483,25 @@ class ResourceTest(testtools.TestCase):
         self.assertEqual("test-human-id", robj.name)
         self.assertEqual(5, robj.test_attr)
 
-    def tes___eq__(self):
+    def test___eq__(self):
         robj = self.get_mock_resource_obj()
         other = base.Resource()
 
         info_ = {"name": "test-human-id", "test_attr": 5}
         robj._info = info_
         other._info = {}
-        self.assertNotTrue(robj.__eq__(other))
-
-        robj._info = info_
-        self.assertTrue(robj.__eq__(other))
+        self.assertFalse(robj.__eq__(other))
 
         robj.id = "rid"
         other.id = "oid"
-        self.assertNotTrue(robj.__eq__(other))
+        self.assertFalse(robj.__eq__(other))
 
         other.id = "rid"
         self.assertTrue(robj.__eq__(other))
 
         # not instance of the same class
         other = mock.Mock()
-        self.assertNotTrue(robj.__eq__(other))
+        self.assertEqual(robj.__eq__(other), NotImplemented)
 
     def test_is_loaded(self):
         robj = self.get_mock_resource_obj()
